@@ -126,7 +126,7 @@ class Escrow:
             open(filename,'w+').write('0')
         current = int(open(filename).read().strip())
         current+=money
-        open(filename).write(current)
+        open(filename).write(str(current))
 
     #Get the current amount of revenue
     def getRevenue(self,filename="revenue.txt"):
